==> aws-cdk.assertions-1.144.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_assertions_MatchFailure(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.matcher))
        _aws_cdk_assertions_Matcher(p.matcher);
    visitedObjects.delete(p);
}
function _aws_cdk_assertions_MatchCapture(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.capture))
        _aws_cdk_assertions_Capture(p.capture);
    visitedObjects.delete(p);
}
function _aws_cdk_assertions_Matcher(p) {
}
function _aws_cdk_assertions_Capture(p) {
}
function _aws_cdk_assertions_Template(p) {
}
function _aws_cdk_assertions_Annotations(p) {
}
function _aws_cdk_assertions_MatchResult(p) {
}
function _aws_cdk_assertions_Match(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_assertions_MatchFailure, _aws_cdk_assertions_MatchCapture, _aws_cdk_assertions_Matcher, _aws_cdk_assertions_Capture, _aws_cdk_assertions_Template, _aws_cdk_assertions_Annotations, _aws_cdk_assertions_MatchResult, _aws_cdk_assertions_Match };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.assertions-1.145.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_assertions_MatchCapture(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.capture))
        _aws_cdk_assertions_Capture(p.capture);
    visitedObjects.delete(p);
}
function _aws_cdk_assertions_MatchFailure(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.matcher))
        _aws_cdk_assertions_Matcher(p.matcher);
    visitedObjects.delete(p);
}
function _aws_cdk_assertions_Matcher(p) {
}
function _aws_cdk_assertions_Capture(p) {
}
function _aws_cdk_assertions_Template(p) {
}
function _aws_cdk_assertions_Annotations(p) {
}
function _aws_cdk_assertions_MatchResult(p) {
}
function _aws_cdk_assertions_Match(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_assertions_MatchCapture, _aws_cdk_assertions_MatchFailure, _aws_cdk_assertions_Matcher, _aws_cdk_assertions_Capture, _aws_cdk_assertions_Template, _aws_cdk_assertions_Annotations, _aws_cdk_assertions_MatchResult, _aws_cdk_assertions_Match };
module.exports.DeprecationError = DeprecationError;
